"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
// Helpers
const getFieldMetadata = (attributes) => {
    const fieldAttributes = {};
    const fields = Object.keys(attributes).filter((item) => {
        return (attributes[item].customField ===
            "plugin::strapi-bootstrap-icons.bootstrap-icon");
    });
    fields.forEach((item) => {
        fieldAttributes[item] = attributes[item];
    });
    return { fields, fieldAttributes };
};
const getIconBuffer = (value) => {
    try {
        const icon = fs_1.default.readFileSync(require.resolve(`bootstrap-icons/icons/${value}.svg`));
        return icon;
    }
    catch (err) {
        return null;
    }
};
const getIconResponseValue = (value, format) => {
    if (format === "class") {
        return value;
    }
    else {
        const buffer = getIconBuffer(value);
        if (buffer) {
            if (format === "svg") {
                return buffer.toString("utf8").replace(/(\r\n|\n|\r)/gm, "");
            }
            return `data:image/svg+xml;base64,${buffer.toString("base64")}`;
        }
        return value;
    }
};
exports.default = ({ strapi }) => ({
    manipulateFindOne(objs) {
        var _a;
        if (objs === null || objs === void 0 ? void 0 : objs.result) {
            const attributes = (_a = objs === null || objs === void 0 ? void 0 : objs.model) === null || _a === void 0 ? void 0 : _a.attributes;
            if (attributes) {
                const result = objs.result;
                const { fields, fieldAttributes } = getFieldMetadata(attributes);
                if (fields.length > 0) {
                    fields.forEach((item) => {
                        var _a;
                        if (!result["updatedBy"] && result[item] !== undefined) {
                            const fieldOptions = (_a = fieldAttributes[item]) === null || _a === void 0 ? void 0 : _a.options;
                            const format = fieldOptions
                                ? fieldOptions["response-format"]
                                : "base64";
                            const value = getIconResponseValue(result[item], format);
                            result[item] = value;
                        }
                    });
                }
            }
        }
    },
    manipulateFindMany(objs) {
        var _a, _b;
        if (((_a = objs === null || objs === void 0 ? void 0 : objs.result) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            const attributes = (_b = objs === null || objs === void 0 ? void 0 : objs.model) === null || _b === void 0 ? void 0 : _b.attributes;
            if (attributes) {
                const results = objs.result;
                const { fields, fieldAttributes } = getFieldMetadata(attributes);
                if (fields.length > 0) {
                    fields.forEach((item) => {
                        results.forEach(async (result) => {
                            var _a;
                            if (!result["updatedBy"] && result[item] !== undefined) {
                                const fieldOptions = (_a = fieldAttributes[item]) === null || _a === void 0 ? void 0 : _a.options;
                                const format = fieldOptions
                                    ? fieldOptions["response-format"]
                                    : "base64";
                                const value = getIconResponseValue(result[item], format);
                                result[item] = value;
                            }
                        });
                    });
                }
            }
        }
    },
});
